;                        Configure the 2000A Processor.
;
;
; This include file configures the CPU and I/O card cage to contain the
; necessary device interfaces in the proper card slots.  It is invoked by the
; 2000A command files, as follows:
;
;    do spconfig.inc <tape-model>
;
; ...where <tape-model> is the model of the magnetic tape drive to be used when
; SLEEPing the system.  If the model is "7970", then the 7970B tape drive is
; used; otherwise, the 3030 drive is used.  This file is never invoked directly
; by the user.
;
; These device assignments are listed in the "HP 2000A Time Share System
; Computer Maintenance Course" (HP part number 5951-1346, January 1971):
;
;    SC  Device  Interface Description
;    --  ------  -----------------------------------------------------------
;    10   MPT    12584A-01 Teleprinter Multiplexer Interface
;    11   TTY    12531C Buffered Teleprinter Interface
;    12   TBG    12539C Time Base Generator Interface
;    13   PTR    12597A-002 Tape Reader Interface
;    14   DRD    12610B Drum Memory Interface Data Channel
;    15   DRC    12610B Drum Memory Interface Command Channel
;  / 16   MTD    12559C 9-Track Magnetic Tape Unit Interface Data Channel
;  \ 17   MTC    12559C 9-Track Magnetic Tape Unit Interface Command Channel
;  / 16   MSD    13181B Digital Magnetic Tape Unit Interface Data Channel
;  \ 17   MSC    13181B Digital Magnetic Tape Unit Interface Command Channel
;    20   MPD    12584A-02 Dataset Multiplexer Interface
;
;
; NOTES:
;
;  - If modem control over user sessions is not desired, the dataset multiplexer
;    (MPD device) may be disabled by commenting its configuration line below.
;    TSB must also be notified by issuing a PHONES-0 command during startup to
;    disable modem control or PHONES-20 to enable support.  With support
;    enabled, logging out of a session with the BYE command also drops DTR,
;    which disconnects Telnet sessions.  With support disabled, all connected
;    sessions remain connected after logging out of TSB.
;
;  - TSB must be notified of the type of tape drive used by issuing the MAGTAPE
;    command during system startup.  Issuing MAGTAPE-16 configures the 3030
;    drive (12559C interface), MAGTAPE-16* configures a 7970 (13181B interface)
;    drive, and MAGTAPE-0 configures the system without a tape drive.


; Configure the CPU.
;
; The processor requires EAU and power-fail/auto-restart support, which must be
; enabled explicitly for the 2116.

set CPU 2116,16K,EAU,ARS


; Configure and assign the select codes of the required devices.

set ALL DISABLED

set MPT ENABLED,SC=10
set TTY ENABLED,SC=11
set TBG ENABLED,SC=12
set PTR ENABLED,SC=13
set DRD ENABLED,SC=14
set MPD ENABLED,SC=20

if "%1" == "7970" set MSD ENABLED,SC=16 ; set MSC 13181
if "%1" != "7970" set MTD ENABLED,SC=16


; Configure the disc drive model.

set DRC 1536K


; Display the I/O configuration to the system operator.

show CPU IOCAGE
echo
